==> jc-1.4.0.tar.gz: gnu/xml/xpath/XPathParser__24YyDgotoClass.h <==
// public final class gnu.xml.xpath.XPathParser$YyDgotoClass

// class file dependencies
// @dep_class d2f023f6a1b94ff7 gnu_xml_xpath_XPathParser__24YyDgotoClass
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_xpath_XPathParser__24YyDgotoClass_H_
#define _JC_gnu_xml_xpath_XPathParser__24YyDgotoClass_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$sub_refs	_jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$sub_refs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$sub_nonrefs	_jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$sub_nonrefs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$refs	_jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$refs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$nonrefs	_jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$nonrefs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$object	_jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$object;

typedef struct _jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$fields_struct	_jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$fields_struct;
typedef const struct _jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$vmethods	_jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$vmethods;
typedef const struct _jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$vtable	_jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$vtable;
typedef const struct _jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$vtype	_jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$vtype;

// Class fields structure
struct _jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$fields_struct {
	_jc_short_array	*yyDgoto;
};
extern _jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$fields_struct _jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$class_fields;

// Constructors
extern void _jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$object *);

// Static methods
extern void _jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$vmethods {
};

// Vtable
struct _jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$vmethods	gnu_xml_xpath_XPathParser__24YyDgotoClass;
};

// Vtype
struct _jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$vtype {
	_jc_type			type;
	_jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$refs {
    _jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$sub_refs	gnu_xml_xpath_XPathParser__24YyDgotoClass;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$sub_nonrefs	gnu_xml_xpath_XPathParser__24YyDgotoClass;
};

// Object instance structure
struct _jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$object {
	_jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$vtype	*vtype;
	_jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$vtype _jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_xpath_XPathParser__24YyDgotoClass, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$class_object;

#endif	/* _JC_gnu_xml_xpath_XPathParser__24YyDgotoClass_H_ */

==> jc-1.4.5.tar.gz: gnu/xml/xpath/XPathParser__24YyDgotoClass.h <==
// public final class gnu.xml.xpath.XPathParser$YyDgotoClass

// class file dependencies
// @dep_class d2f023f6a1b94ff7 gnu_xml_xpath_XPathParser__24YyDgotoClass
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_xpath_XPathParser__24YyDgotoClass_H_
#define _JC_gnu_xml_xpath_XPathParser__24YyDgotoClass_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$sub_refs	_jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$sub_refs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$sub_nonrefs	_jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$sub_nonrefs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$refs	_jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$refs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$nonrefs	_jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$nonrefs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$object	_jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$object;

typedef struct _jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$fields_struct	_jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$fields_struct;
typedef const struct _jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$vmethods	_jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$vmethods;
typedef const struct _jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$vtable	_jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$vtable;
typedef const struct _jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$vtype	_jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$vtype;

// Class fields structure
struct _jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$fields_struct {
	_jc_short_array	*yyDgoto;
};
extern _jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$fields_struct _jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$class_fields;

// Constructors
extern void _jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$vmethods {
};

// Vtable
struct _jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$vmethods	gnu_xml_xpath_XPathParser__24YyDgotoClass;
};

// Vtype
struct _jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$vtype {
	_jc_type			type;
	_jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$refs {
    _jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$sub_refs	gnu_xml_xpath_XPathParser__24YyDgotoClass;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$sub_nonrefs	gnu_xml_xpath_XPathParser__24YyDgotoClass;
};

// Object instance structure
struct _jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$object {
	_jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$vtype	*vtype;
	_jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$vtype _jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_xpath_XPathParser__24YyDgotoClass, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_xpath_XPathParser__24YyDgotoClass$class_object;

#endif	/* _JC_gnu_xml_xpath_XPathParser__24YyDgotoClass_H_ */
